@@ -21,3 +21,15 @@ class Dispatch(View):
         else:
             data['error'] = 'invalid model name'
         return HttpResponse(json.dumps(data))
+
+    def post(self, *args, **kwargs):
+        model = models_list[kwargs.get('model')]['model']
+        if model:
+            if model.to_obj:
+                obj = model.to_obj(self.request.body)
+                obj.save()
+            else:
+                serializer = model.serializer_class(data=json.loads(self.request.body))
+                if serializer.is_valid():
+                    serializer.object.save()
+        return HttpResponse()
